package mutil

import (
	"fmt"
	"strings"
)

func AddParam(base string, param string) string {
	base = strings.TrimSuffix(base, "/")
	return fmt.Sprintf("%s/{%s}", base, param)
}

func AddAccountRef(base string) string {
	return AddParam(base, AccountRefName())
}

func AddObjRef(base string) string {
	return AddParam(base, ObjRefName())
}

func AddOrganizaztionRef(base string) string {
	return AddParam(base, OrganizationRefName())
}

func AddStatusRef(base string) string {
	return AddParam(base, StatusRefName())
}

func AddProjectRef(base string) string {
	return AddParam(base, ProjectRefName())
}

func AddInvitationRef(base string) string {
	return AddParam(base, InvitationRefName())
}

func AddToken(base string) string {
	return AddParam(base, TokenName())
}
